@@ -2,5 +2,5 @@ pub use crate::app::{Pizarra, SaveStatus, MouseButton, ShouldRedraw, SelectedToo
 pub use crate::transform::Transform;
 pub use crate::point::{Vec2DScreen, Vec2DWorld, Point};
 pub use crate::color::Color;
-pub use crate::shape::ShapeType;
+pub use crate::shape::ShapeTool;
 pub use crate::key::Key;
